@@ -24,10 +24,11 @@ class Recipe:
             buildout['buildout']['parts-directory'],
             name)
 
-        # We look for a download directory, where we put the download tarballs
-        buildout['buildout'].setdefault(
-                    'download-cache',
-                    os.path.join(buildout['buildout']['directory'], 'downloads'))
+        # If 'download-cache' has not been specified, look for 'download-directory';
+        # finally, fallback to buildout/downloads.
+        buildout['buildout'].setdefault('download-cache', \
+                buildout['buildout'].get('download-directory', \
+                os.path.join(buildout['buildout']['directory'], 'downloads')))
 
     def install(self):
         dest = self.options['location']
